package com.goldenwater.slaj.ttsa.mapper;

import java.util.List;
import org.apache.ibatis.annotations.Mapper;
import com.goldenwater.slaj.ttsa.domain.BisTtsaCertChaPers;

@Mapper
public interface BisTtsaCertChaPersMapper {
    BisTtsaCertChaPers selectBisTtsaCertChaPersByGuid(String guid);
    List<BisTtsaCertChaPers> selectBisTtsaCertChaPersList(BisTtsaCertChaPers bisTtsaCertChaPers);
    int insertBisTtsaCertChaPers(BisTtsaCertChaPers bisTtsaCertChaPers);
    int updateBisTtsaCertChaPers(BisTtsaCertChaPers bisTtsaCertChaPers);
    int deleteBisTtsaCertChaPersByGuid(String guid);
    int deleteBisTtsaCertChaPersByGuids(String[] guids);
}
